@@ -102,9 +102,20 @@ class Mod:
         tmp_name = self.fileName[:-4] + '.gz'
         try:
             os.rename(self.fileName, tmp_name)
-            is_file_writable(self.fileName + '.tbi', force)
             pysam.tabix_index(tmp_name, force=True, seq_col=1, start_col=2,
                               end_col=2, meta_char='#', zerobased=True)
+            if os.path.getsize(tmp_name + '.tbi') < 100: #something wrong with indexing
+                print("Warning: abnormal index size. Rebuilding index ...")
+                fp = self.bgz_open(tmp_name)
+                with open(self.fileName[:-4], 'w') as txt_fp:
+                    for line in fp:
+                        txt_fp.write(line)
+                self.bgz_close(fp)
+                pysam.tabix_compress(self.fileName[:-4], tmp_name, force=True)
+                pysam.tabix_index(tmp_name, force=True, seq_col=1, start_col=2,
+                                  end_col=2, meta_char='#', zerobased=True)
+                os.remove(self.fileName[:-4])
+            is_file_writable(self.fileName + '.tbi', force)
             os.rename(tmp_name + '.tbi', self.fileName + '.tbi')
         finally:
             os.rename(tmp_name, self.fileName)
@@ -191,7 +202,35 @@ class Mod:
         #print(self.meta)
         self.bgz_close(bgz_fp)
 
-        assert 'refmeta' in self.meta, "Required 'refmeta' field not found."
+        #assert 'refmeta' in self.meta, "Required 'refmeta' field not found."
+        # for backward compatibility, if no refmeta, assume it is mm9 reference
+        if 'refmeta' not in self.meta:
+            print("Warning: Required 'refmeta' field not found. Using mm9 genome as reference")
+            mm9_meta = dict()
+            mm9_meta['1']  = RefMeta('chr1', '197195432', 'f05d753079c455c0e57af88eeda24493')
+            mm9_meta['2']  = RefMeta('chr2', '181748087', '9b9d64dc89ecc73d3288eb38af3f94bd')
+            mm9_meta['3']  = RefMeta('chr3', '159599783', '0a692666a1b8526e1d1e799beb71b6d0')
+            mm9_meta['4']  = RefMeta('chr4', '155630120', 'f5993a04396a06ed6b28fa42b2429be0')
+            mm9_meta['5']  = RefMeta('chr5', '152537259', 'f90804fb8fe9cb06076d51a710fb4563')
+            mm9_meta['6']  = RefMeta('chr6', '149517037', '258a37e20815bb7e3f2e974b9d4dd295')
+            mm9_meta['7']  = RefMeta('chr7', '152524553', 'e0d6cea6f72cb4d9f8d0efc1d29dd180')
+            mm9_meta['8']  = RefMeta('chr8', '131738871', '5f217cb8a9685b9879add3ae110cabd7')
+            mm9_meta['9']  = RefMeta('chr9', '124076172', 'dde08574942fc18050195618cc3f35af')
+            mm9_meta['10'] = RefMeta('chr10', '129993255', 'be7e6a13cc6b9da7c1da7b7fc32c5506')
+            mm9_meta['11'] = RefMeta('chr11', '121843856', 'e0099550b3d3943fb9bb7af6fa6952c1')
+            mm9_meta['12'] = RefMeta('chr12', '121257530', '1f9c11dc6f288f93e9fab56772a36e85')
+            mm9_meta['13'] = RefMeta('chr13', '120284312', 'a7b4bb418aa21e0ec59d9e2a1fe1810b')
+            mm9_meta['14'] = RefMeta('chr14', '125194864', '09d1c8449706a17d40934302a0a3b671')
+            mm9_meta['15'] = RefMeta('chr15', '103494974', 'e41c8b42b0921378b1fdd5172f6be067')
+            mm9_meta['16'] = RefMeta('chr16', '98319150', 'e051b3930c2557ade21d67db41f3a518')
+            mm9_meta['17'] = RefMeta('chr17', '95272651', '47eede15e5761fb9c2267627f18211e7')
+            mm9_meta['18'] = RefMeta('chr18', '90772031', '9f9d41cfdb9d91b62b928a3eb4eb6928')
+            mm9_meta['19'] = RefMeta('chr19', '61342430', '591f8486f82c22442bb8463595a18e0a')
+            mm9_meta['X']  = RefMeta('chrX', '166650296', '3d0d9df898d2c830b858f91255d8a1eb')
+            mm9_meta['Y']  = RefMeta('chrY', '15902555', '5ff564f9fbc8cb87bcad6cfa6874902b')
+            mm9_meta['M']  = RefMeta('chrM', '16299', '11c8af2a2528b25f2c080ab7da42edda')
+            self.meta['refmeta'] = mm9_meta
+
         self.refmeta = self.meta['refmeta']
         self.all_chroms = set(self.refmeta.keys())
         #print(self.refmeta)
